@@ -1,11 +1,12 @@
 # Initialize Auth Package
 from .core import HttpAuthenticator, NoAuth
 from .oauth import Oauth2Authenticator
-from .token import TokenAuthenticator
+from .token import MultipleTokenAuthenticator, TokenAuthenticator
 
 __all__ = [
     "HttpAuthenticator",
     "NoAuth",
     "Oauth2Authenticator",
     "TokenAuthenticator",
+    "MultipleTokenAuthenticator",
 ]
